# Chucks

[![PyPI - Version](https://img.shields.io/pypi/v/chucks.svg)](https://pypi.org/project/chucks)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/chucks.svg)](https://pypi.org/project/chucks)

-----

## Table of Contents

- [Installation](#installation)
- [License](#license)

## Installation

```console
pip install chucks
```

## TODO
- [ ] Pandas wrappers.
- [ ] Analysis scripts.
- [ ] Pandas extensions.
- [ ] Explore the suggestion of using another Schwab python library for orders.

## License

This project does not include a license. All rights reserved.
